pub trait StashStatus {
// Required method
fn stashed_messages(&self) -> usize;
}Expand description
Semantic observation of the outermost composed stash, independent of its structural nesting depth.
pub trait StashStatus {
// Required method
fn stashed_messages(&self) -> usize;
}Semantic observation of the outermost composed stash, independent of its structural nesting depth.